@@ -140,39 +140,39 @@
 #'
 #' @author Ioannis Kosmidis [aut, cre] \email{ioannis.kosmidis@warwick.ac.uk}, Euloge Clovis Kenne Pagui [ctb] \email{kenne@stat.unipd.it}
 #'
-#' @seealso \code{\link{glm.fit}} and \code{\link{glm}}
+#' @seealso \code{\link{brglmControl}}, \code{\link{glm.fit}}, \code{\link{glm}}
 #'
 #' @references
 #'
 #' Kosmidis I, Firth D (2020). Jeffreys-prior penalty, finiteness
 #' and shrinkage in binomial-response generalized linear
-#' models. *Biometrika* \url{https://doi.org/10.1093/biomet/asaa052}
+#' models. *Biometrika* \doi{10.1093/biomet/asaa052}
 #'
 #' Kosmidis I, Kenne Pagui E C, Sartori N (2020). Mean and median bias
 #' reduction in generalized linear models. *Statistics and Computing*,
-#' **30**, 43-59 \url{https://doi.org/10.1007/s11222-019-09860-6}
+#' **30**, 43-59 \doi{10.1007/s11222-019-09860-6}
 #'
 #' Cordeiro G M, McCullagh P (1991). Bias correction in generalized
 #' linear models. *Journal of the Royal Statistical Society. Series B
-#' (Methodological)*, **53**, 629-643 \url{https://doi.org/10.1111/j.2517-6161.1991.tb01852.x}
+#' (Methodological)*, **53**, 629-643 \doi{10.1111/j.2517-6161.1991.tb01852.x}
 #'
 #' Firth D (1993). Bias reduction of maximum likelihood estimates.
-#' *Biometrika*. **80**, 27-38 \url{https://doi.org/10.2307/2336755}
+#' *Biometrika*. **80**, 27-38 \doi{10.2307/2336755}
 #'
 #' Kenne Pagui E C, Salvan A, Sartori N (2017). Median bias
 #' reduction of maximum likelihood estimates. *Biometrika*, **104**,
-#' 923–938 \url{https://doi.org/10.1093/biomet/asx046}
+#' 923–938 \doi{10.1093/biomet/asx046}
 #'
 #' Kosmidis I, Firth D (2009). Bias reduction in exponential family
-#' nonlinear models. *Biometrika*, **96**, 793-804 \url{https://doi.org/10.1093/biomet/asp055}
+#' nonlinear models. *Biometrika*, **96**, 793-804 \doi{10.1093/biomet/asp055}
 #'
 #' Kosmidis I, Firth D (2010). A generic algorithm for reducing
 #' bias in parametric estimation. *Electronic Journal of Statistics*,
-#' **4**, 1097-1112 \url{https://doi.org/10.1214/10-EJS579}
+#' **4**, 1097-1112 \doi{10.1214/10-EJS579}
 #'
 #' Kosmidis I (2014). Bias in parametric estimation: reduction and
 #' useful side-effects. *WIRE Computational Statistics*, **6**,
-#' 185-196 \url{https://doi.org/10.1002/wics.1296}
+#' 185-196 \doi{10.1002/wics.1296}
 #'
 #' @examples
 #' ## The lizards example from ?brglm::brglm
@@ -675,6 +675,7 @@ brglmFit <- function(x, y, weights = rep(1, nobs), start = NULL, etastart = NULL
     ## Ensure x is a matrix, extract variable names, observation
     ## names, nobs, nvars, and initialize weights and offsets if
     ## needed
+
     x <- as.matrix(x)
     betas_names <- dimnames(x)[[2L]]
     nvars <- ncol(x)
@@ -778,25 +779,31 @@ brglmFit <- function(x, y, weights = rep(1, nobs), start = NULL, etastart = NULL
     else {
         boundary <- converged <- FALSE
         ## Detect aliasing
-        qrx <- qr(x)
-        rank <- qrx$rank
-        is_full_rank <- rank == nvars
-
-        if (!singular.ok && !is_full_rank) {
-            stop("singular fit encountered")
-        }
-        if (!isTRUE(is_full_rank)) {
-            aliased <- qrx$pivot[seq.int(qrx$rank + 1, nvars)]
-            X_all <- x
-            x <- x[, -aliased]
-            nvars_all <- nvars
-            nvars <- ncol(x)
+        if (!isTRUE(control$check_aliasing)) {
+            is_full_rank <- TRUE ## Assumption
+            rank <- nvars_all <- nvars
             betas_names_all <- betas_names
-            betas_names <- betas_names[-aliased]
         }
         else {
-            nvars_all <- nvars
-            betas_names_all <- betas_names
+            qrx <- qr(x)
+            rank <- qrx$rank
+            is_full_rank <- rank == nvars
+            if (!isTRUE(singular.ok) && !isTRUE(is_full_rank)) {
+                stop("singular fit encountered")
+            }
+            if (!isTRUE(is_full_rank)) {
+                aliased <- qrx$pivot[seq.int(qrx$rank + 1, nvars)]
+                X_all <- x
+                x <- x[, -aliased]
+                nvars_all <- nvars
+                nvars <- ncol(x)
+                betas_names_all <- betas_names
+                betas_names <- betas_names[-aliased]
+            }
+            else {
+                nvars_all <- nvars
+                betas_names_all <- betas_names
+            }
         }
         betas_all <- structure(rep(NA_real_, nvars_all), .Names = betas_names_all)
         keep <- weights > 0
